﻿//   Copyright 2023 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at

//       https://www.apache.org/licenses/LICENSE-2.0

//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License. 

using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Mapping;
using System.Linq;

namespace EditingCustomizations
{
  internal class Duplicate : Button
  {
    protected override async void OnClick()
    {
      await QueuedTask.Run(async () =>
      {
        var sSet = FrameworkApplication.ContextMenuDataContextAs<SelectionSet>();
        if (sSet == null)
          return;

        int count = sSet.Count;
        if (count == 0)
          return;

        var sSetDict = sSet.ToDictionary();
        var mm = sSetDict.Keys.FirstOrDefault();
        if (mm == null)
          return;

        var op = new EditOperation();
        op.Name = "Duplicate Rows";

        op.Copy(mm, mm, sSetDict[mm]);
        await op.ExecuteAsync();
      });
    }
  }
}
